@@ -11,7 +11,7 @@ function(profile, pc, hub.h, rho=1.225, avail=1, bins=c(5,10,15,20), sectoral=FA
 	
 	if(is.null(attr(profile, "call"))) stop(paste(substitute(profile), "is no profile object\n"))
 	if(attr(profile, "call")$func!="profile") stop(paste(substitute(profile), "is no profile object\n"))
-	if(is.null(attr(pc, "call"))) stop(paste(substitute(profile), "is no profile object\n"))
+	if(is.null(attr(pc, "call"))) stop(paste(substitute(pc), "is no profile object\n"))
 	if(attr(pc, "call")$func!="readPC" & attr(pc, "call")$func!="createPC") stop(paste(substitute(pc), "is no power curve object - use create.pc to create a power curve or read.pc to import a power curve from file\n"))
 	if(!is.numeric(hub.h)) stop("'hub.h' must be numeric\n")
 	if(!is.numeric(rho)) stop("'rho' must be numeric\n")
