@@ -31,7 +31,8 @@ function(mast, set, v.avg.min=0.4, v.avg.max=50, dir.clean=TRUE, turb.clean=4, i
 		if(is.null(attr(mast, "call"))) stop(paste(substitute(mast), "is no mast object"))
 		if(attr(mast, "call")$func!="createMast") stop(paste(substitute(mast), "is no mast object"))
 		num.sets <- length(mast$sets)
-		if(!is.numeric(set)) stop("Please specify 'set' as number\n")
+		if(!is.numeric(set)) set <- match(set, names(mast$sets))
+		if(is.na(set)) stop("Set not found\n")
 		if(set<0 || set>num.sets) stop("Set not found\n")
 		cat("Cleaning set", set, "...\n")
 		mast$sets[[set]]$data <- cleanInt(mast$sets[[set]]$data, v.avg.min, v.avg.max, dir.clean, turb.clean, icing, rep, n.rep+1)
