@@ -5,7 +5,8 @@ function(mast, set, ...) {
 	if(is.null(attr(mast, "call"))) stop(paste(substitute(mast), "is no mast object"))
 	if(attr(mast, "call")$func!="createMast") stop(paste(substitute(mast), "is no mast object"))
 	num.sets <- length(mast$sets)
-	if(!is.numeric(set)) stop("'set' must be numeric\n")
+	if(!is.numeric(set)) set <- match(set, names(mast$sets))
+	if(is.na(set)) stop("'set' not found\n")
 	if(set<0 || set>num.sets) stop("'set' not found\n")
 	if(is.null(mast$sets[[set]]$data$turb.int)) stop("Specified set does not contain turbulence intensity data\n")
 	unit <- attr(mast$sets[[set]]$data$v.avg, "unit")
